@@ -624,7 +624,6 @@ notify_notification_update_internal (NotifyNotification *notification,
 
         if (priv->icon_name != icon) {
                 gchar *snapped_icon;
-                const char *hint_name = NULL;
 
                 g_free (priv->icon_name);
                 priv->icon_name = (icon != NULL
@@ -637,22 +636,10 @@ notify_notification_update_internal (NotifyNotification *notification,
                         priv->icon_name = snapped_icon;
                 }
 
-                if (_notify_check_spec_version(1, 2)) {
-                    hint_name = "image-path";
-                } else if (_notify_check_spec_version(1, 1)) {
-                    hint_name = "image_path";
-                } else {
-                    /* Before 1.1 only one image/icon could be specified and the
-                     * icon_data hint didn't allow for a path or icon name,
-                     * therefore the icon is set as the app icon of the Notify call */
-                }
-
-                if (hint_name) {
-                    notify_notification_set_hint (notification,
-                                                  hint_name,
-                                                  priv->icon_name ?
-                                                  g_variant_new_string (priv->icon_name) : NULL);
-                }
+                notify_notification_set_hint (notification,
+                                              NOTIFY_NOTIFICATION_HINT_IMAGE_PATH,
+                                              priv->icon_name ?
+                                              g_variant_new_string (priv->icon_name) : NULL);
 
                 g_object_notify (G_OBJECT (notification), "icon-name");
         }
@@ -1045,7 +1032,7 @@ add_portal_notification (GDBusProxy         *proxy,
                                        g_variant_builder_end (&buttons));
         }
 
-        urgency = g_hash_table_lookup (priv->hints, "urgency");
+        urgency = g_hash_table_lookup (priv->hints, NOTIFY_NOTIFICATION_HINT_URGENCY);
         if (urgency) {
                 switch (g_variant_get_byte (urgency)) {
                 case NOTIFY_URGENCY_LOW:
@@ -1119,6 +1106,38 @@ add_portal_notification (GDBusProxy         *proxy,
         return TRUE;
 }
 
+const char *
+get_hint_name (NotifyNotification *notification,
+               const char         *hint)
+{
+        if (g_str_equal (hint, NOTIFY_NOTIFICATION_HINT_IMAGE_DATA)) {
+                if (_notify_check_spec_version (1, 2)) {
+                        return hint;
+                }
+                if (_notify_check_spec_version (1, 1)) {
+                        return NOTIFY_NOTIFICATION_HINT_IMAGE_DATA_LEGACY;
+                }
+                return "icon_data";
+        }
+
+        if (g_str_equal (hint, NOTIFY_NOTIFICATION_HINT_IMAGE_PATH)) {
+                if (_notify_check_spec_version (1, 2)) {
+                        return hint;
+                }
+                if (_notify_check_spec_version (1, 1)) {
+                        return NOTIFY_NOTIFICATION_HINT_IMAGE_PATH_LEGACY;
+                }
+
+                /* Before 1.1 only one image/icon could be specified and the
+                 * icon_data hint didn't allow for a path or icon name,
+                 * therefore the icon is set as the app icon of the Notify call
+                 */
+                return NULL;
+        }
+
+        return hint;
+}
+
 /**
  * notify_notification_show:
  * @notification: The notification.
@@ -1177,7 +1196,12 @@ notify_notification_show (NotifyNotification *notification,
         g_variant_builder_init (&hints_builder, G_VARIANT_TYPE ("a{sv}"));
         g_hash_table_iter_init (&iter, priv->hints);
         while (g_hash_table_iter_next (&iter, &key, &data)) {
-                g_variant_builder_add (&hints_builder, "{sv}", key, data);
+                const char *hint = get_hint_name (notification, key);
+                if (!hint) {
+                        continue;
+                }
+
+                g_variant_builder_add (&hints_builder, "{sv}", hint, data);
         }
 
         if (g_hash_table_lookup (priv->hints, "sender-pid") == NULL) {
@@ -1186,7 +1210,8 @@ notify_notification_show (NotifyNotification *notification,
         }
 
         if (_notify_get_snap_app () &&
-            g_hash_table_lookup (priv->hints, "desktop-entry") == NULL) {
+            g_hash_table_lookup (priv->hints,
+                                 NOTIFY_NOTIFICATION_HINT_DESKTOP_ENTRY) == NULL) {
                 gchar *snap_desktop;
 
                 snap_desktop = g_strdup_printf ("%s_%s",
@@ -1195,7 +1220,7 @@ notify_notification_show (NotifyNotification *notification,
 
                 g_debug ("Using desktop entry: %s", snap_desktop);
                 g_variant_builder_add (&hints_builder, "{sv}",
-                                       "desktop-entry",
+                                       NOTIFY_NOTIFICATION_HINT_DESKTOP_ENTRY,
                                        g_variant_new_take_string (snap_desktop));
         }
 
@@ -1204,13 +1229,15 @@ notify_notification_show (NotifyNotification *notification,
         }
 
         if (application != NULL) {
-            GVariant *desktop_entry = g_hash_table_lookup (priv->hints, "desktop-entry");
+            GVariant *desktop_entry = g_hash_table_lookup (priv->hints,
+                                                           NOTIFY_NOTIFICATION_HINT_DESKTOP_ENTRY);
 
             if (desktop_entry == NULL) {
                 const char *application_id = g_application_get_application_id (application);
 
                 g_debug ("Using desktop entry: %s", application_id);
-                g_variant_builder_add (&hints_builder, "{sv}", "desktop-entry",
+                g_variant_builder_add (&hints_builder, "{sv}",
+                                       NOTIFY_NOTIFICATION_HINT_DESKTOP_ENTRY,
                                        g_variant_new_string (application_id));
             }
         }
@@ -1218,7 +1245,7 @@ notify_notification_show (NotifyNotification *notification,
         app_icon = priv->app_icon ? priv->app_icon : notify_get_app_icon ();
 
         /* Use the icon_name as app icon only before there was a hint for it */
-        if (!app_icon && !_notify_check_spec_version(1, 1)) {
+        if (!app_icon && !_notify_check_spec_version (1, 1)) {
             app_icon = priv->icon_name;
         }
 
@@ -1311,7 +1338,7 @@ notify_notification_set_category (NotifyNotification *notification,
 
         if (category != NULL && category[0] != '\0') {
                 notify_notification_set_hint_string (notification,
-                                                     "category",
+                                                     NOTIFY_NOTIFICATION_HINT_CATEGORY,
                                                      category);
         }
 }
@@ -1330,7 +1357,7 @@ notify_notification_set_urgency (NotifyNotification *notification,
         g_return_if_fail (NOTIFY_IS_NOTIFICATION (notification));
 
         notify_notification_set_hint_byte (notification,
-                                           "urgency",
+                                           NOTIFY_NOTIFICATION_HINT_URGENCY,
                                            (guchar) urgency);
 }
 
@@ -1374,22 +1401,15 @@ notify_notification_set_image_from_pixbuf (NotifyNotification *notification,
         gboolean        has_alpha;
         gsize           image_len;
         GVariant       *value;
-        const char     *hint_name;
 
         g_return_if_fail (pixbuf == NULL || GDK_IS_PIXBUF (pixbuf));
 
-        if (_notify_check_spec_version(1, 2)) {
-                hint_name = "image-data";
-        } else if (_notify_check_spec_version(1, 1)) {
-                hint_name = "image_data";
-        } else {
-                hint_name = "icon_data";
-        }
-
         g_clear_object (&priv->icon_pixbuf);
 
         if (pixbuf == NULL) {
-                notify_notification_set_hint (notification, hint_name, NULL);
+                notify_notification_set_hint (notification,
+                                              NOTIFY_NOTIFICATION_HINT_IMAGE_DATA,
+                                              NULL);
                 return;
         }
 
@@ -1423,7 +1443,9 @@ notify_notification_set_image_from_pixbuf (NotifyNotification *notification,
                                                         TRUE,
                                                         (GDestroyNotify) g_object_unref,
                                                         g_object_ref (pixbuf)));
-        notify_notification_set_hint (notification, hint_name, value);
+        notify_notification_set_hint (notification,
+                                      NOTIFY_NOTIFICATION_HINT_IMAGE_DATA,
+                                      value);
 }
 
 typedef gchar * (*StringParserFunc) (NotifyNotification *, const gchar *);
@@ -1457,11 +1479,11 @@ maybe_parse_snap_hint_value (NotifyNotification *notification,
         if (!_notify_get_snap_path ())
                 return value;
 
-        if (g_strcmp0 (key, "desktop-entry") == 0) {
+        if (g_strcmp0 (key, NOTIFY_NOTIFICATION_HINT_DESKTOP_ENTRY) == 0) {
                 parse_func = try_prepend_snap_desktop;
-        } else if (g_strcmp0 (key, "image-path") == 0 ||
-                   g_strcmp0 (key, "image_path") == 0 ||
-                   g_strcmp0 (key, "sound-file") == 0) {
+        } else if (g_strcmp0 (key, NOTIFY_NOTIFICATION_HINT_IMAGE_PATH) == 0 ||
+                   g_strcmp0 (key, NOTIFY_NOTIFICATION_HINT_IMAGE_PATH_LEGACY) == 0 ||
+                   g_strcmp0 (key, NOTIFY_NOTIFICATION_HINT_SOUND_FILE) == 0) {
                 parse_func = try_prepend_snap;
         }
 
